@@ -54,7 +54,7 @@ class ModelsEvaluator:
         with torch.no_grad():
             print("torch.no_grad() go:")
             for feature_vector, label, _id in zip(X_eval, y_eval, ids):
-
+                print("type(_id) :", type(_id))
                 log_probs = model(feature_vector)
                 # get confidence that item is disaster-related
                 prob_related = math.exp(log_probs.data.tolist()[0][1])
@@ -65,19 +65,19 @@ class ModelsEvaluator:
                     related_confs.append(prob_related)
                     if prob_related > 0.5:
                         true_pos += 1.0
-                        true_pos_text.append(text_data[_id][1])
+                        true_pos_text.append(text_data[str(_id)][1])
                     else:
                         false_neg += 1.0
-                        false_neg_text.append(text_data[_id][1])
+                        false_neg_text.append(text_data[str(_id)][1])
                 else:
                     # not disaster-related
                     not_related_confs.append(prob_related)
                     if prob_related > 0.5:
                         false_pos += 1.0
-                        false_pos_text.append(text_data[_id][1])
+                        false_pos_text.append(text_data[str(_id)][1])
                     else:
                         true_neg += 1.0
-                        true_neg_text.append(text_data[_id][1])
+                        true_neg_text.append(text_data[str(_id)][1])
 
         # Get FScore
         if true_pos == 0.0:
